================================================
Generative Adversarial Imitation Learning (GAIL)
================================================

Implements `Generative Adversarial Imitation Learning <https://arxiv.org/abs/1606.03476>`_.

API
===
.. autoclass:: imitation.algorithms.adversarial.gail.GAIL
    :members:
    :inherited-members:
    :noindex:

.. autoclass:: imitation.algorithms.adversarial.common.AdversarialTrainer
    :members:
    :inherited-members:
    :noindex:
